notify_focus_change

Function notify_focus_change 

pub fn notify_focus_change()
Notify all text inputs that a different widget has taken focus. This causes any focused text input to unfocus on its next layout.