pub fn select_until_last<Message: 'static>( id: Id, value: &str, ch: char, ) -> Task<Message>
Produces a Task that selects from the front to the last occurrence of the given character in the TextInput with the given Id, or selects all if not found.
Task
TextInput
Id